@@ -37,7 +37,7 @@
 #include "build_run.h"
 
 /* print usage lines */
-static inline void u(const char *fmt, ...)
+RND_INLINE void u(const char *fmt, ...)
 {
 	va_list ap;
 	va_start(ap, fmt);
