@@ -32,15 +32,13 @@
 
 typedef struct camv_text_s {
 	CAMV_ANY_PRIMITIVE_FIELDS;
-	rnd_coord_t x, y;
-	int size;
-	double rot;
+	rnd_coord_t x, y;         /* placement: specify center bottom point of text */
+	double rot;               /* in degrees */
 	char *s;
 
 	/* internal/cache */
-	void *ttf_pm; /* (ttf2bbox_pixmap_t *) */
-	rnd_pixmap_t *pm;
-	rnd_coord_t sx, sy;
+	rnd_coord_t cx[4], cy[4]; /* 4 corners of the rotated bbox */
+	rnd_coord_t dx, dy;       /* offsets from x,y to librnd font renderer */
 } camv_text_t;
 
 void camv_text_init(camv_text_t *text);
