@@ -34,6 +34,6 @@
 #define PREF_TAB 0
 #include "dlg_pref_general.c"
 
-int pcb_dlg_pref_tab = PREF_TAB;
-void (*pcb_dlg_pref_first_init)(pref_ctx_t *ctx, int tab) = PREF_INIT_FUNC;
+int camv_dlg_pref_tab = PREF_TAB;
+void (*camv_dlg_pref_first_init)(pref_ctx_t *ctx, int tab) = PREF_INIT_FUNC;
 
