@@ -35,6 +35,7 @@
 #include "event.h"
 #include <librnd/core/actions.h>
 #include <librnd/hid/hid.h>
+#include <librnd/hid/hid_export.h>
 #include <librnd/core/hidlib.h>
 #include <librnd/core/rnd_conf.h>
 #include <librnd/core/compat_misc.h>
@@ -144,6 +145,7 @@ static fgw_error_t camv_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	static char *last_project = NULL, *last_layer = NULL;
 	const char *function = "Layer";
 	char *name = NULL;
+	int multisel = 0;
 
 	if (last_layer == NULL)     last_layer = dup_cwd();
 	if (last_project == NULL)   last_project = dup_cwd();
@@ -154,10 +156,14 @@ static fgw_error_t camv_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Load, function = argv[1].val.str);
 
-	if (rnd_strcasecmp(function, "Layer") == 0)
-		name = rnd_hid_fileselect(rnd_gui, "Load layer", "Import a layer from file", last_layer, NULL, NULL, "layer", RND_HID_FSD_READ, NULL);
-	else if (rnd_strcasecmp(function, "Project") == 0)
+	if (rnd_strcasecmp(function, "Layer") == 0) {
+		name = rnd_hid_fileselect(rnd_gui, "Load layer", "Import a layer from file", last_layer, NULL, NULL, "layer", RND_HID_FSD_READ | RND_HID_FSD_MULTI, NULL);
+		multisel = 1;
+	}
+	else if (rnd_strcasecmp(function, "Project") == 0) {
 		name = rnd_hid_fileselect(rnd_gui, "Load a project file", "load project (all layers) from file", last_project, ".lht", NULL, "project", RND_HID_FSD_READ, NULL);
+		multisel = 0;
+	}
 	else {
 		rnd_message(RND_MSG_ERROR, "Invalid subcommand for Load(): '%s'\n", function);
 		RND_ACT_IRES(1);
@@ -165,9 +171,19 @@ static fgw_error_t camv_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	if (name != NULL) {
-		if (rnd_conf.rc.verbose)
-			fprintf(stderr, "Load:  Calling LoadFrom(%s, %s)\n", function, name);
-		rnd_actionl("LoadFrom", function, name, NULL);
+		if (multisel) {
+			char *n;
+			for(n = name; *n != '\0'; n += strlen(n)+1) {
+				if (rnd_conf.rc.verbose)
+					fprintf(stderr, "Load:  Calling LoadFrom(%s, %s)\n", function, n);
+				rnd_actionl("LoadFrom", function, n, NULL);
+			}
+		}
+		else {
+			if (rnd_conf.rc.verbose)
+				fprintf(stderr, "Load:  Calling LoadFrom(%s, %s)\n", function, name);
+			rnd_actionl("LoadFrom", function, name, NULL);
+		}
 		free(name);
 	}
 
@@ -329,6 +345,7 @@ static rnd_action_t camv_gui_action_list[] = {
 	{"PrintGUI", rnd_act_PrintDialog, rnd_acth_PrintDialog, rnd_acts_PrintDialog},
 	{"Popup", camv_act_Popup, camv_acth_Popup, camv_acts_Popup},
 	{"Load", camv_act_Load, camv_acth_Load, camv_acts_Load},
+	{"Export", rnd_act_Export, rnd_acth_Export, rnd_acts_Export},
 	{"Layer", camv_act_Layer, camv_acth_Layer, camv_acts_Layer},
 	{"StatusSetText", camv_act_StatusSetText, camv_acth_StatusSetText, camv_acts_StatusSetText},
 	{"Save", camv_act_Save, camv_acth_Save, camv_acts_Save},
