@@ -192,7 +192,7 @@ static int gcode_execute_code_do(gcode_prg_t *prg)
 	return ctx->state.stop;
 }
 
-#define CN(code,num) (((unsigned)code << 16) | (unsigned)((double)num*10.0))
+#define CN(code,num) (unsigned)((((unsigned)code << 16) | (unsigned)((double)num*10.0)))
 
 static int gcode_execute_code_(gcode_prg_t *prg, int code, double param)
 {
