@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2022 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 #include <genht/htip.h>
 #include <genht/hash.h>
 
+#include <librnd/core/hidlib.h>
+#include <librnd/core/conf_multi.h>
 #include <librnd/core/error.h>
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/compat_misc.h>
@@ -45,6 +47,13 @@
 #include "gcode_vm.h"
 #include "gcode_exec.h"
 
+#include "import_gcode_conf.h"
+
+conf_import_gcode_t conf_import_gcode;
+static const char io_gcode_cookie[] = "io_gcode";
+
+#include "conf_internal.c"
+
 typedef struct {
 	htip_t h2l; /* height-to-layer */
 	const char *fn;
@@ -145,7 +154,7 @@ static int camv_gcode_load(camv_design_t *camv, const char *fn, FILE *fin)
 	if (gcodeparse(&prg) != 0)
 		return 1;
 
-	prg.cfg.laser = conf_core.plugins.import_gcode.laser;
+	prg.cfg.laser = conf_import_gcode.plugins.import_gcode.laser;
 	gcode_execute_init(&prg, &ops);
 	gcode_execute(&prg);
 	gcode_execute_uninit(&prg);
@@ -185,11 +194,19 @@ int pplg_check_ver_import_gcode(int ver_needed) { return 0; }
 
 void pplg_uninit_import_gcode(void)
 {
+	rnd_conf_plug_unreg("plugins/import_gcode/", import_gcode_conf_internal, io_gcode_cookie);
 	camv_io_unreg(&io_gcode);
 }
 
 int pplg_init_import_gcode(void)
 {
 	camv_io_reg(&io_gcode);
+
+	rnd_conf_plug_reg(conf_import_gcode, import_gcode_conf_internal, io_gcode_cookie);
+
+#define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
+	rnd_conf_reg_field(conf_import_gcode, field,isarray,type_name,cpath,cname,desc,flags);
+#include "import_gcode_conf_fields.h"
+
 	return 0;
 }
