@@ -289,15 +289,25 @@
 		} \
 	} while(0)
 
-#define READ_APERTURE(_ctx_, _aid_) \
+#define READ_APERTURE(_ctx_, _aid_, _allow_empty_) \
 	do { \
 		int __c__; \
 		READ(_ctx_, __c__); \
-		if (__c__ != 'D') { \
-			_ctx_->errmsg = "Expected 'D' for aperture ID"; \
-			return GEP_ERROR; \
+		if (__c__ != '*') { \
+			if (__c__ != 'D') { \
+				_ctx_->errmsg = "Expected 'D' for aperture ID"; \
+				return GEP_ERROR; \
+			} \
+			READ_NUM(_ctx_, _aid_); \
+		} \
+		else { \
+			if (!_allow_empty_) { \
+				_ctx_->errmsg = "Expected 'D' for aperture ID - empty aperture not supported in this context"; \
+				return GEP_ERROR; \
+			} \
+			else \
+				_aid_ = -42; \
 		} \
-		READ_NUM(_ctx_, _aid_); \
 	} while(0)
 
 /* Append a macro name into a gds string, utnil endchr or '*' (endchr is not consumed) */
@@ -658,7 +668,11 @@ static ge_parse_res_t geparse_aperture_add(geparse_ctx_t *ctx)
 	int c1, c2, c;
 	long aid;
 
-	READ_APERTURE(ctx, aid);
+	READ_APERTURE(ctx, aid, 1);
+	if (aid == -42) {
+		READ_LONGEND(ctx);
+		return GEP_NEXT;
+	}
 	if (aid < 10) {
 		ctx->errmsg = "invalid aperture ID: must be at least 10";
 		return GEP_ERROR;
@@ -875,6 +889,13 @@ ge_parse_res_t geparse_long_cmd(geparse_ctx_t *ctx)
 			READ_TILL_CMDEND(ctx);
 			break;
 
+		/* offset and scale factor -> ignore for now */
+		case CMD('O', 'F'):
+		case CMD('S', 'F'):
+			READ_TILL_CMDEND(ctx);
+			break;
+
+
 		default:
 			ctx->errmsg = "unrecognized long command";
 			return GEP_ERROR;
