@@ -757,7 +757,7 @@ static void gedraw_do_pol_(camv_design_t *camv, const camv_layer_t *main_layer,
 	(*ly)->sub = 1;
 	(*ly)->clearing = clearing;
 	(*ly)->color = main_layer->color;
-	camv_layer_append_to_design(camv, *ly);
+	camv->loader.ly = camv_sublayer_append_after(camv, *ly, camv->loader.ly);
 }
 
 static void gedraw_do_pol(camv_design_t *camv, const camv_layer_t *main_layer, camv_layer_t **ly, gerbst_t *curr, gerbst_t *last)
@@ -1156,7 +1156,7 @@ static int gedraw_camv(camv_design_t *camv, gedraw_ctx_t *ctx, const char *name)
 
 	ly->name = rnd_strdup(name);
 	camv_layer_invent_color(camv, ly); /* gerber files do not have layer color */
-	camv_layer_append_to_design(camv, ly);
+	camv->loader.ly = camv_layer_append_to_design(camv, ly);
 
 	memset(&curr, 0, sizeof(curr));
 	curr.interp = GEI_LIN;
